<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

use Teknisa\CNC\Services\Cnc02200ErrorLogService;

class Cnc02200ErrorLog {
    protected $dataSourceName = 'cnc02200_error_log';
	protected $parameterBagColumns;
	
	public function __construct (Cnc02200ErrorLogService $service) {
	    $this->service = $service;
	}
	
	public function findAll (DTO\Request\Filter $request, DTO\Response $response) {
		try {
	        $row = $request->getFilterCriteria()->getConditions();
	        
	        $params["NRORG"] = array_filter($row, function($param) {
	            return $param["columnName"] === "NRORG";
	        });
	        $params["NRORG"] = array_shift($params["NRORG"])["value"];
	        $result = $this->service->findAll($params);
	        $response->addDataSet(new DataSet('cnc02200_error_log', $result));
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}
	public function find (DTO\Request\Filter $request, DTO\Response $response) {
	    try {
	        $row = $request->getFilterCriteria()->getConditions();
	        $params["NRORG"] = array_filter($row, function($param) {
	            return $param["columnName"] === "NRORG";
	        });
	        $params["NRORG"] = array_shift($params["NRORG"])["value"];
	        $params["NRESTABELEC"] = array_filter($row, function($param) {
                return $param["columnName"] === "NRESTABELEC";
            });
            
            if(count($params["NRESTABELEC"]) > 0){
	            $params["NRESTABELEC"] = array_shift($params["NRESTABELEC"])["value"];
	            $params["NRESTABELEC"] = array_reduce($params["NRESTABELEC"], function($acc, $estabelec) {
	                return $acc."|".$estabelec;
	            })."|";
            } else{
            	$params["NRESTABELEC"] = 'T';
            }
	        $result = $this->service->find($params);
	        $response->addDataSet(new DataSet('cnc02200_error_log', $result));
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}
	
	public function runProcFinanc (DTO\Request\Row $request, DTO\Response $response) {
	    try {
            $row = $request->getRow();
            
            $row["DATE"] = $this->service->getDateFromErrorLog($row);
            
            $bool = $this->service->runProcFinanc($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
	}
	
	public function countErrors (DTO\Request\Filter $request, DTO\Response $response) {
	    try {
	        $row = $request->getFilterCriteria()->getConditions();

	        $params["NRORG"] = array_filter($row, function($param) {
	            return $param["columnName"] === "NRORG";
	        });
	        $params["NRORG"] = array_shift($params["NRORG"])["value"];
	        
	        $params["NRESTABELEC"] = array_filter($row, function($param) {
                return $param["columnName"] === "NRESTABELEC";
            });
            $params["NRESTABELEC"] = array_shift($params["NRESTABELEC"])["value"];
            $params["NRESTABELEC"] = array_reduce($params["NRESTABELEC"], function($acc, $estabelec) {
                return $acc."|".$estabelec."|";
            });
        	
	        $result = $this->service->countErrors($params);
	        $response->addDataSet(new DataSet('cnc02200_error_log_countErrors', [$result]));
	    } catch (\Exception $e) {
	        $response->setError(new Error($e->getMessage(), $e->getCode()));
	    }
	}
	
	public function countErrorsForCard (DTO\Request\Filter $request, DTO\Response $response) {
		try {
			$row = $request->getFilterCriteria()->getConditions();
	        
	        $params["NRORG"] = array_filter($row, function($param) {
	            return $param["columnName"] === "NRORG";
	        });
	        $params["NRORG"] = array_shift($params["NRORG"])["value"];
	        
	        $result = $this->service->countErrorsForCard($params);
	        $response->addDataSet(new DataSet('cnc02200_countErrorsForCard', [$result]));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), $e->getCode()));
		}
	}
}