<?php

namespace Teknisa\CNC\Factories;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Cnc03100DesconciliacaoVendasFactory {
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function conciliacoesSelect ($params) {
        $sql = "SELECT T.CDNSU, T.NRAUTORIZACAO, T.DTVENDA, T.NMPRODUTOADQ, T.VRBRUTVENDA, T.NRCONCLANC, T.NRCONCLANCPGTO, T.CHAVE, T.DTCREDITO,
                T.DRECEBE, T.NRLANCTONF, T.NRLANBOLREC, T.CDFILIALNF, T.CDFILIAL, T.CDFILIAL||'-'||T.NMFILIAL AS NMFILIAL, 
                (T.VRBRUTVENDA - (T.VRBRUTVENDA * (NVL(TF.VRTAXAADMFIL, T.VRTAXAADMI)/100))) AS VRLIQVENDA,
                T.NRPARCELA, T.NRPARCELAREC, T.NMTIPORECE, NVL(TF.CDCLIENTE, T.CDCLIENTE) AS CDCLIENTE, 
                NVL(TF.CDTPCTRECEB, T.CDTPCTRECEB) AS CDTPCTRECEB, NVL(TF.CDAJTXADMREC, T.CDAJTXADMREC) AS CDAJTXADMREC,
                T.CDTIPORECE, T.NRCONSMOVCAIXA, T.CDEMPRESA, T.NRSEQUMOVI, T.CDCAIXA, T.DTABERCAIX AS DTABERCAIX, T.NRORG, T.NRNOTAFISC,
                TO_CHAR(T.DTEMISSAO,'DD/MM/YYYY') AS DTEMISSAO, T.CDFILIBOLREC, TO_CHAR(T.DTVENBOLREC,'DD/MM/YYYY') AS DTVENBOLREC, T.CDLOTECTB AS CDLOTE
                FROM 
                (SELECT C.CDNSU, C.NRAUTORIZACAO, TO_CHAR(C.DTVENDA, 'DD/MM/YYYY') DTVENDA, P.NMPRODUTOADQ,
                C.VRVENDA VRBRUTVENDA, C.NRCONCLANC, null NRCONCLANCPGTO, C.NRCONSMOVCAIXA CHAVE, C.NRCONSMOVCAIXA, F.CDEMPRESA,
                TO_CHAR(NVL(C.DTVENCIMENTO, CNC_DATA_VENC(C.CDFILIAL, C.DTVENDA, NVL(P.NRDIASVENC, 0), C.CDTIPORECE)), 'DD/MM/YYYY') DTCREDITO,
                NVL(C.DTVENCIMENTO, CNC_DATA_VENC(C.CDFILIAL, C.DTVENDA, NVL(P.NRDIASVENC, 0), C.CDTIPORECE)) - C.DTVENDA AS DRECEBE,
                C.NRLANCTONF, C.CDFILIALNF, EF.CDFILIAL, F.NMFILIAL, NVL(TPRECE.VRTAXAADMI, 0) VRTAXAADMI, C.NRPARCELA, TPRECE.NMTIPORECE, 
                C.CDTIPORECE, TPRECE.CDCLIENTE, TPRECE.CDTPCTRECEB, TPRECE.CDAJTXADMREC, CTR.NRPARCELAREC, CTR.NRLANBOLREC, C.NRSEQUMOVI, 
                C.CDCAIXA, C.DTABERCAIX AS DTABERCAIX, C.NRORG, NF.NRNOTAFISC, NF.DTEMISSAO, CTR.CDFILIBOLREC, BR.DTVENBOLREC, C.CDLOTECTB
                FROM CONSMOVCAIXA C
                LEFT JOIN CONCILIACAOLANC CON
                       ON C.NRCONCLANC = CON.NRCONCLANC
                LEFT JOIN CONTARECEBER CTR
                       ON CTR.CDFILIAL = C.CDFILIALNF
                      AND CTR.NRLANCTONF = C.NRLANCTONF
                LEFT JOIN BOLETRECEBER BR
                       ON BR.NRLANBOLREC = CTR.NRLANBOLREC
                      AND BR.CDFILIAL = CTR.CDFILIAL
                LEFT JOIN NOTAFISCAL NF
                       ON NF.CDFILIAL = C.CDFILIALNF
                      AND NF.NRLANCTONF = C.NRLANCTONF
                LEFT JOIN TIPORECE TPRECE
                       ON TPRECE.CDTIPORECE = C.CDTIPORECE
                LEFT JOIN TPRECEPRODADQ TP
                       ON C.CDTIPORECE = TP.CDTIPORECE
                LEFT JOIN PRODUTOADQ P
                       ON P.NRPRODUTOADQ = TP.NRPRODUTOADQ,
                (SELECT DISTINCT CDFILIAL
                FROM ESTABELECIMENTO
                WHERE ((INSTR (:NRESTABELEC, '|'||TO_CHAR(NRESTABELEC)||'|') > 0) OR :TNRESTABELEC = 'T')) EF
                JOIN FILIAL F
                  ON F.CDFILIAL = EF.CDFILIAL
                WHERE C.CDFILIAL = EF.CDFILIAL
                AND C.NRORG = :NRORG
                AND ((INSTR (:NRPRODUTOADQ, '|'||TO_CHAR(P.NRPRODUTOADQ)||'|') > 0) OR :TNRPRODUTOADQ = 'T')
                AND C.DTVENDA BETWEEN :DTVENDA_MIN AND :DTVENDA_MAX
                AND ((UPPER(C.CDNSU) LIKE UPPER('%'||:CDNSU||'%')) OR ('T' = :TCDNSU))
                AND C.IDCONCILIADO = 'C'
                ORDER BY DTVENDA, F.NMFILIAL, P.NMPRODUTOADQ, C.VRVENDA, C.CDNSU) T
                LEFT JOIN TIPORECEFILIAL TF
                       ON TF.CDFILIAL = T.CDFILIAL
                      AND TF.CDTIPORECE = T.CDTIPORECE";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function verificaConciliacoesSimultaneas($params){
        $sql = "SELECT COUNT(NRCONCLANC) AS NRCONCLANC
            FROM CONSMOVCAIXA
           WHERE NRCONCLANC = :NRCONCLANC";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function verifyContReceb($params){
        $sql = "SELECT 1 AS FLAGBOLETO
              FROM CONTARECEBER C
             WHERE C.CDFILIAL = :CDFILIAL
               AND C.NRLANCTONF = :NRLANCTONF
               AND C.IDSTATREC = 'B'  ";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function getDatasVendas($params){
        $sql = "SELECT DISTINCT DTVENDA
                  FROM CONSMOVCAIXA
                 WHERE NRCONCLANC = :NRCONCLANC";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function deleteItemCorVenda ($params) {
        $sql = "DELETE FROM ITEMCORVENDA
                WHERE NRCONSMOVCAIXA = :NRCONSMOVCAIXA";
                  
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteCAPALOTE ($params) {
        $sql = "DELETE FROM CAPALOTE
                WHERE CDLOTE = :CDLOTE
                  AND CDEMPRESA = :CDEMPRESA";
                  
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteRATECCUS ($params) {
        $sql = "DELETE FROM RATECCUS
                WHERE CDLOTE = :CDLOTE
                  AND CDEMPRESA = :CDEMPRESA";
                  
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteLANCLOTE ($params) {
        $sql = "DELETE FROM LANCLOTE
                WHERE CDLOTE = :CDLOTE
                  AND CDEMPRESA = :CDEMPRESA";
                  
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteLANCCONT ($params) {
        $sql = "DELETE FROM LANCCONT
                WHERE NRLANCCONT = :NRLANCCONT
                  AND CDEMPRESA = :CDEMPRESA";
                  
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function nullifyRowsAtConsMovCaixa ($params) {
        $sql = "UPDATE CONSMOVCAIXA
                SET NRCONCLANC = null,
                    IDCONCILIADO = 'P',
                    IDSITUACAO = 'N'
                WHERE NRORG = :NRORG
                  AND NRCONCLANC = :NRCONCLANC
                  AND CDFILIAL = :CDFILIAL";
        
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function nullifyRowsAtRetVendaAdq ($params) {
        $sql = "UPDATE RETVENDAADQ
		    SET NRCONCLANC = null,
		    	NRCONCLANCPGTO = null,
		    	IDCONCILIADO = 'P',
		    	IDSITUACAO = 'N',
                NRLANCTONF = null,
                CDFILIAL = null
		 WHERE NRCONCLANC = :NRCONCLANC
		   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function nullifyRowsAtRetFinancAdq ($params) {
        $sql = "UPDATE RETFINANCADQ
                SET NRCONCLANC = null,
                    IDCONCILIADO = 'P',
                    IDSITUACAO = 'N'
                WHERE NRORG = :NRORG
                  AND NRCONCLANC = :NRCONCLANC";
                  
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteFromDivConciliacaoConvmovcaixa ($params) {
        $sql = "DELETE FROM DIVCONCILIACAO
                WHERE NRORG = :NRORG
                  AND NRCONSMOVCAIXA = :NRCONSMOVCAIXA";
                  
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteFromDivConciliacao ($params) {
        $sql = "DELETE FROM DIVCONCILIACAO
                WHERE NRORG = :NRORG
                  AND NRCONCLANC = :NRCONCLANC";
                  
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteFromConciliacaoLanc ($params) {
        $sql = "DELETE FROM CONCILIACAOLANC
                WHERE NRORG = :NRORG
                  AND NRCONCLANC = :NRCONCLANC";
                  
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function verifyContaReceberInfo ($params) {
        $sql = "SELECT CDFILIBOLREC, NRLANBOLREC, VRATUAREC, NRPARCELAREC, NRLANCTONF, CDFILIAL
                FROM CONTARECEBER
                WHERE NRLANCTONF = :NRLANCTONF
                  AND  CDFILIAL  = :CDFILIAL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function verifyBoletReceberInfo($params){
        $sql = "SELECT VRFINALBREC, CDFILIAL AS CDFILIBOLREC, NRLANBOLREC FROM BOLETRECEBER
            WHERE CDFILIAL = :CDFILIBOLREC 
            AND NRLANBOLREC = :NRLANBOLREC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function verifyBoletConta($params){
        $sql = "SELECT :CDFILIAL AS CDFILIAL, :NRLANBOLREC AS NRLANBOLREC, COUNT(C.NRLANCTONF) AS TOT, SUM(VRATUAREC) AS TOTBOLET
          FROM CONTARECEBER C
          JOIN NOTAFISCAL N
            ON C.NRLANCTONF = N.NRLANCTONF
           AND C.CDFILIAL = N.CDFILIAL
          JOIN CONSMOVCAIXA CM
            ON CM.CDFILIALNF = N.CDFILIAL
           AND CM.NRLANCTONF = N.NRLANCTONF
	     WHERE N.IDSISTEMA = 'CNC'
		   AND C.NRLANBOLREC = :NRLANBOLREC
           AND C.CDFILIBOLREC = :CDFILIAL
         GROUP BY :CDFILIAL, :NRLANBOLREC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function nullifyBoletContaReceber($params){
        $sql = "    
        UPDATE CONTARECEBER
            SET NRLANBOLREC = NULL,
                CDFILIBOLREC = NULL
            WHERE NRLANCTONF = :NRLANCTONF
              AND  CDFILIAL  = :CDFILIAL";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteTipoReceBoletReceber($params){
        $sql = "    
        DELETE FROM TPRECBOLETO
		 WHERE CDFILIAL = :CDFILIAL
           AND NRLANBOLREC = :NRLANBOLREC";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function updateTipoReceBoletReceber($params){
        $sql = "    
        UPDATE TPRECBOLETO
           SET VRTPRECBOLR = :TOTBOLET
		 WHERE CDFILIAL = :CDFILIAL
           AND NRLANBOLREC = :NRLANBOLREC";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteBoletReceber($params){
        $sql = "    
		DELETE FROM BOLETRECEBER
		 WHERE CDFILIAL = :CDFILIAL
           AND NRLANBOLREC = :NRLANBOLREC";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function updateBoletReceber($params){
        $sql = "    
		UPDATE BOLETRECEBER
		   SET VRBOLREC = :TOTBOLET, VRFINALBREC = :TOTBOLET
		 WHERE CDFILIAL = :CDFILIAL
           AND NRLANBOLREC = :NRLANBOLREC";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteAjCtReceber($params){
        $sql = "    
		DELETE FROM AJCTRECEBER
		 WHERE CDFILIAL = :CDFILIAL
           AND NRLANCTONF = :NRLANCTONF";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteCtReceber($params){
        $sql = "    
		DELETE FROM CONTARECEBER
		 WHERE CDFILIAL = :CDFILIAL
           AND NRLANCTONF = :NRLANCTONF";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function updateFinancConsMovCaixa($params){
        $sql = "    
    	UPDATE CONSMOVCAIXA
           SET CDFILIALNF = NULL,
               NRLANCTONF= NULL
         WHERE CDFILIALNF = :CDFILIAL 
           AND NRCONSMOVCAIXA = :NRCONSMOVCAIXA";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteNotaFiscal($params){
        $sql = "    
		DELETE FROM NOTAFISCAL
		 WHERE CDFILIAL = :CDFILIAL
           AND NRLANCTONF = :NRLANCTONF";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function updateMovCaixa($params){
        $sql = "    
    	UPDATE MOVCAIXA
           SET IDREPLICADOCNC = 'N'
         WHERE CDFILIAL = :CDFILIAL 
           AND CDCAIXA = :CDCAIXA
           AND NRSEQUMOVI = :NRSEQUMOVI
           AND DTABERCAIX = :DTABERCAIX";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteConsMovCaixa($params){
        $sql = "    
   		 DELETE FROM CONSMOVCAIXA
		   WHERE NRCONSMOVCAIXA = :NRCONSMOVCAIXA";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function executaReplicacao($data){
        $data = str_replace(' 00:00:00', '', $data);
        
        $connection = $this->connection;
        $storedProcedure = new StoredProcedure($connection, 'REPLICACAO_FOS_CNC');
        $storedProcedure->addParam($this->buildInputParam('P_DATAINI', $data));
        $storedProcedure->addParam($this->buildInputParam('P_DATAFIN', $data));
        
        $result = $storedProcedure->execute();
        
        return $result;
    }
    
    public function executaReverteLote($params){
        $connection = $this->connection;
        $storedProcedure = new StoredProcedure($connection, 'REVERTE_LOTE');
        $storedProcedure->addParam($this->buildInputParam('P_CDEMPRESA', $params['CDEMPRESA']));
        $storedProcedure->addParam($this->buildInputParam('P_CDLOTE', $params['CDLOTE']));
        
        $result = $storedProcedure->execute();
        
        return $result;
    }
    
    private function buildInputParam ($paramName, $paramValue) {
        return new Param($paramName, Param::PARAM_INPUT, $paramValue, Param::PARAM_TYPE_STR, strlen($paramValue));
    }
    
    public function verifyInfoConsmov($param){ 
        $sql = "
        SELECT DISTINCT CONS.NRCONCLANC, CONS.NRCONSMOVCAIXA, CONS.CDFILIAL, CONS.CDFILIALNF, CONS.NRLANCTONF, CTR.CDTPCTRECEB,
                CTR.DTATUAVENREC, CONS.DTVENDA, CONS.CDTIPORECE,
                NF.CDTIPOOPER, NF.CDEMPRESA CDEMPRESA_NF, NF.CDINSCESTA CDINSCESTA_NF, NF.CDINSCMUNI CDINSCMUNI_NF, NF.CDSERIE CDSERIE_NF, NF.CDCLIENTE,
                EST.CDEMPRESA CDEMPRESA_ESTABELEC, EST.CDINSCESTA CDINSCESTA_ESTABELEC, EST.CDINSCMUNI CDINSCMUNI_ESTABELEC, EST.CDSERIE CDSERIE_ESTABELEC,
                CONS.DTVENCIMENTO, CTR.NRPARCELAREC, CONS.NRPARCELA, CONS.NRQTPARCELA AS NRQTPARCELA
        FROM CONSMOVCAIXA CONS
            JOIN NOTAFISCAL NF
              ON NF.CDFILIAL = CONS.CDFILIALNF
              AND NF.NRLANCTONF = CONS.NRLANCTONF
            JOIN CONTARECEBER CTR
              ON CTR.CDFILIAL = CONS.CDFILIALNF
              AND CTR.NRLANCTONF = CONS.NRLANCTONF
            JOIN ESTABELECIMENTO EST
              ON EST.CDFILIAL = CONS.CDFILIAL
        WHERE CONS.NRCONSMOVCAIXA = :NRCONSMOVCAIXA
          AND CONS.NRORG = :NRORG";
            
        $std = $this->connection->prepare($sql);
        $std->execute($param);
        $retorno = $std->fetch();
        
        if(!$retorno){
            try{ 
                $procedure = new StoredProcedure($this->connection, 'FINANCEIRO_FOS_CNC');
                $procedure->addParam(new Param('P_NRCONSMOVCAIXA', Param::PARAM_INPUT, $param[':NRCONSMOVCAIXA']));
                $procedure->execute();
                $std = $this->connection->prepare($sql);
                $std->execute($param);
                $retorno = $std->fetch();
            } catch (\Exception $e) {
                    throw $e;
            }
        }
        return $retorno;
    }
    
    public function verifyInfoTpReceb($params){
        $sql="
        SELECT NVL(P.CDREDUCONT, T.CDREDUCONT) CDREDUCONT
          FROM TIPORECE T, PARAVEND P
        WHERE T.CDTIPORECE = :CDTIPORECE
          AND P.CDFILIAL = :CDFILIAL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function createBoletRec($params){
      try{ 
            $procedure = new StoredProcedure($this->connection, 'GERA_BOLETOS_REC');
            $procedure->addParam(new Param('P_NRLANBOLREC', Param::PARAM_INPUT, $params["P_NRLANBOLREC"]));
            $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $params["P_CDFILIAL"]));
            $procedure->addParam(new Param('P_CDCLIENTE', Param::PARAM_INPUT, $params["P_CDCLIENTE"]));
            $procedure->addParam(new Param('P_CDEMPRESA', Param::PARAM_INPUT, $params["P_CDEMPRESA"]));
            $procedure->addParam(new Param('P_VRBOLREC', Param::PARAM_INPUT, $params["P_VRBOLREC"]));
            $procedure->addParam(new Param('P_DTVENBOL', Param::PARAM_INPUT, $params["P_DTVENBOL"]));
            $procedure->addParam(new Param('P_CDTIPORECE', Param::PARAM_INPUT, $params["P_CDTIPORECE"]));
            $procedure->addParam(new Param('P_NRCHEQUEVEND', Param::PARAM_INPUT, $params["P_NRCHEQUEVEND"]));
            $procedure->addParam(new Param('P_CDBANCHEQVEN', Param::PARAM_INPUT, $params["P_CDBANCHEQVEN"]));
            $procedure->addParam(new Param('P_CDAGECHEQVEN', Param::PARAM_INPUT, $params["P_CDAGECHEQVEN"]));
            $procedure->addParam(new Param('P_CDCNTCHEQVEN', Param::PARAM_INPUT, $params["P_CDCNTCHEQVEN"]));
            $procedure->addParam(new Param('P_CDREDUCONT', Param::PARAM_INPUT, $params["P_CDREDUCONT"]));
            $procedure->addParam(new Param('P_CDTPBAIXA', Param::PARAM_INPUT, $params["P_CDTPBAIXA"]));
            $procedure->addParam(new Param('P_DTVENDAECF', Param::PARAM_INPUT, $params["P_DTVENDAECF"]));

            return $procedure->execute();
        } catch (\Exception $e) {
                throw $e;
        }
    }
    
    public function updateContaReceberBol($params){
        $sql = "
        UPDATE CONTARECEBER
        SET CDFILIBOLREC = :CDFILIBOLREC,
            NRLANBOLREC  = :NRLANBOLREC
        WHERE NRLANCTONF = :NRLANCTONF
              AND CDFILIAL       = :CDFILIAL
              AND NRPARCELAREC   = :NRPARCELAREC 
        ";
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function recalculaBoleto($params){
        $sql = "SELECT C.CDFILIBOLREC, C.NRLANBOLREC, C.NRSEQVENREC, C.NRPARCELAREC, SUM(C.VRATUAREC) AS TOTALCONTAS
                  FROM CONTARECEBER C
                WHERE C.CDFILIBOLREC = :CDFILIBOLREC
                  AND C.NRLANBOLREC = :NRLANBOLREC
                GROUP BY C.CDFILIBOLREC, C.NRLANBOLREC, C.NRSEQVENREC, C.NRPARCELAREC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function updateTprecboleto($params){
        $sql = "
        UPDATE TPRECBOLETO
        SET VRTPRECBOLR = :VRTPRECBOLR
        WHERE NRLANBOLREC = :NRLANBOLREC
              AND CDFILIAL   = :CDFILIAL 
        ";
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
    
    public function getMovCaixa($params){
        $sql = "SELECT CDNSUHOSTTEF, VRMOVIVEND, CDTIPORECE, DTMOVIMCAIXA FROM MOVCAIXA
            WHERE CDFILIAL = :CDFILIAL 
            AND CDCAIXA = :CDCAIXA
            AND NRSEQUMOVI = :NRSEQUMOVI
            AND DTABERCAIX = :DTABERCAIX";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function calcNrDiasVenc($params){
        $sql = "         
        SELECT NVL(NVL(PR.NRDIASVENC, T.NRDIASADMI), 0)
           AS V_NRDIASVENC
           FROM TIPORECE T LEFT JOIN PARAVEND P
                                  ON P.CDFILIAL = :CDFILIAL
                           LEFT JOIN PRODUTOADQ PR
                             ON PR.CDTIPORECE = T.CDTIPORECE
          WHERE T.CDTIPORECE = :CDTIPORECE ";
          
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function verifyDataVenc($params){
        $sql="
        SELECT CNC_DATA_VENC(:CDFILIAL, :DTVENDA, :NRDIASVENC, :CDTIPORECE)
        AS V_DTVENCIMENTO
        FROM DUAL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function updateConsMovCaixaDesconciliacao($params){
        $sql = "    
        UPDATE CONSMOVCAIXA
            SET CDNSU = :CDNSU,
                VRVENDA = :VRVENDA,
                CDTIPORECE = :CDTIPORECE,
                DTVENDA = :DTVENDA,
                DTVENCIMENTO = :DTVENCIMENTO
            WHERE NRCONSMOVCAIXA = :NRCONSMOVCAIXA
              AND CDFILIAL  = :CDFILIAL
              AND CDCAIXA = :CDCAIXA
              AND NRSEQUMOVI  = :NRSEQUMOVI
              AND DTABERCAIX  = :DTABERCAIX";
              
        $std = $this->connection->prepare($sql);
        return $std->execute($params);
    }
}