<?php

namespace WebServiceCall\SoapClient;

class SoapHandler implements ISoapHandler {
    private const CONNECTION_FAILED = 'Não foi possível obter conexão para o serviço: ';
    private const EMPTY_RESPONSE = 'Com os parâmetros filtrados, não há dados para o serviço: ';
    
    private $soapConn;
    private $wsServiceName;
    
    public function __construct($soapServerURL, $wsServiceName) {
        $this->wsServiceName = $wsServiceName;
        
        $this->soapConn = new \SoapClient($soapServerURL, array("keep_alive" => true));
        
        if (!$this->soapConn) {
            throw new \Exception(self::CONNECTION_FAILED . $wsServiceName);
        }
    }
    
    public function getServiceName() {
        return $this->wsServiceName;
    }
    
    public function soapCall($params) {
        $response = $this->soapConn->__soapCall($this->wsServiceName, array($params));
        
        if (is_soap_fault($response)) {
            throw new \Exception("SOAP Fault: (faultcode: {$response->faultcode}, faultstring: {$response->faultstring})");
        }
        
        if (!$response) {
            throw new \Exception(self::EMPTY_RESPONSE . $this->wsServiceName);
        }
        
        return $response;
    }
}